==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/Employees/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Employees',
  'LBL_MODULE_TITLE' => 'Employees: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Employee Search',
  'LBL_LIST_FORM_TITLE' => 'Employees',
  'LBL_NEW_FORM_TITLE' => 'New Employee',
  'LBL_EMPLOYEE' => 'Employees:',
  'LBL_LOGIN' => 'Login',
  'LBL_RESET_PREFERENCES' => 'Reset To Default Preferences',
  'LBL_TIME_FORMAT' => 'Time Format:',
  'LBL_DATE_FORMAT' => 'Date Format:',
  'LBL_TIMEZONE' => 'Current Time:',
  'LBL_CURRENCY' => 'Currency:',
  'LBL_LIST_NAME' => 'Name',
  'LBL_LIST_LAST_NAME' => 'Last Name',
  'LBL_LIST_EMPLOYEE_NAME' => 'Employee Name',
  'LBL_LIST_DEPARTMENT' => 'Department',
  'LBL_LIST_REPORTS_TO_NAME' => 'Reports To',
  'LBL_LIST_EMAIL' => 'Email',
  'LBL_LIST_PRIMARY_PHONE' => 'Primary Phone',
  'LBL_LIST_USER_NAME' => 'User Name',
  'LBL_LIST_ADMIN' => 'Admin',
  'LBL_NEW_EMPLOYEE_BUTTON_TITLE' => 'New Employee [Alt+N]',
  'LBL_NEW_EMPLOYEE_BUTTON_LABEL' => 'New Employee',
  'LBL_NEW_EMPLOYEE_BUTTON_KEY' => 'N',
  'LBL_ERROR' => 'Error:',
  'LBL_PASSWORD' => 'Password:',
  'LBL_EMPLOYEE_NAME' => 'Employee Name:',
  'LBL_USER_NAME' => 'User Name:',
  'LBL_FIRST_NAME' => 'First Name:',
  'LBL_LAST_NAME' => 'Last Name:',
  'LBL_EMPLOYEE_SETTINGS' => 'Employee Settings',
  'LBL_THEME' => 'Theme:',
  'LBL_LANGUAGE' => 'Language:',
  'LBL_ADMIN' => 'Administrator:',
  'LBL_EMPLOYEE_INFORMATION' => 'Employee Information',
  'LBL_OFFICE_PHONE' => 'Office Phone:',
  'LBL_REPORTS_TO' => 'Reports to Id:',
  'LBL_REPORTS_TO_NAME' => 'Reports to',
  'LBL_OTHER_PHONE' => 'Other:',
  'LBL_OTHER_EMAIL' => 'Other Email:',
  'LBL_NOTES' => 'Notes:',
  'LBL_DEPARTMENT' => 'Department:',
  'LBL_TITLE' => 'Title:',
  'LBL_ANY_PHONE' => 'Any Phone:',
  'LBL_ANY_EMAIL' => 'Any Email:',
  'LBL_ADDRESS' => 'Address:',
  'LBL_CITY' => 'City:',
  'LBL_STATE' => 'State:',
  'LBL_POSTAL_CODE' => 'Postal Code:',
  'LBL_COUNTRY' => 'Country:',
  'LBL_NAME' => 'Name:',
  'LBL_MOBILE_PHONE' => 'Mobile:',
  'LBL_OTHER' => 'Other:',
  'LBL_FAX' => 'Fax:',
  'LBL_EMAIL' => 'Email Address:',
  'LBL_HOME_PHONE' => 'Home Phone:',
  'LBL_WORK_PHONE' => 'Work Phone:',
  'LBL_ADDRESS_INFORMATION' => 'Address Information',
  'LBL_EMPLOYEE_STATUS' => 'Employee Status:',
  'LBL_PRIMARY_ADDRESS' => 'Primary Address:',
  'LBL_SAVED_SEARCH' => 'Layout Options',
  'LBL_CREATE_USER_BUTTON_TITLE' => 'Create User [Alt+N]',
  'LBL_CREATE_USER_BUTTON_LABEL' => 'Create User',
  'LBL_CREATE_USER_BUTTON_KEY' => 'N',
  'LBL_FAVORITE_COLOR' => 'Favorite Color:',
  'LBL_MESSENGER_ID' => 'IM Name:',
  'LBL_MESSENGER_TYPE' => 'IM Type:',
  'ERR_EMPLOYEE_NAME_EXISTS_1' => 'The employee name ',
  'ERR_EMPLOYEE_NAME_EXISTS_2' => ' already exists.  Duplicate employee names are not allowed.  Change the employee name to be unique.',
  'ERR_LAST_ADMIN_1' => 'The employee name "',
  'ERR_LAST_ADMIN_2' => '" is the last employee with administrator access.  At least one employee must be an administrator.',
  'LNK_NEW_EMPLOYEE' => 'Create Employee',
  'LNK_EMPLOYEE_LIST' => 'Employees',
  'ERR_DELETE_RECORD' => 'You must specify a record number to delete the account.',
  'LBL_LIST_EMPLOYEE_STATUS' => 'Employee Status',

  'LBL_SUGAR_LOGIN' => 'Is Sugar User',  
  'LBL_RECEIVE_NOTIFICATIONS' => 'Notify on Assignment',  
  'LBL_IS_ADMIN' => 'Is Administrator',  
  'LBL_GROUP' => 'Group User',
  'LBL_PORTAL_ONLY'	=> 'Portal Only User',
);


?>

==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/Employees/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Employees',
  'LBL_MODULE_TITLE' => 'Employees: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Employee Search',
  'LBL_LIST_FORM_TITLE' => 'Employees',
  'LBL_NEW_FORM_TITLE' => 'New Employee',
  'LBL_EMPLOYEE' => 'Employees:',
  'LBL_LOGIN' => 'Login',
  'LBL_RESET_PREFERENCES' => 'Reset To Default Preferences',
  'LBL_TIME_FORMAT' => 'Time Format:',
  'LBL_DATE_FORMAT' => 'Date Format:',
  'LBL_TIMEZONE' => 'Current Time:',
  'LBL_CURRENCY' => 'Currency:',
  'LBL_LIST_NAME' => 'Name',
  'LBL_LIST_LAST_NAME' => 'Last Name',
  'LBL_LIST_EMPLOYEE_NAME' => 'Employee Name',
  'LBL_LIST_DEPARTMENT' => 'Department',
  'LBL_LIST_REPORTS_TO_NAME' => 'Reports To',
  'LBL_LIST_EMAIL' => 'Email',
  'LBL_LIST_PRIMARY_PHONE' => 'Primary Phone',
  'LBL_LIST_USER_NAME' => 'User Name',
  'LBL_LIST_ADMIN' => 'Admin',
  'LBL_NEW_EMPLOYEE_BUTTON_TITLE' => 'New Employee [Alt+N]',
  'LBL_NEW_EMPLOYEE_BUTTON_LABEL' => 'New Employee',
  'LBL_NEW_EMPLOYEE_BUTTON_KEY' => 'N',
  'LBL_ERROR' => 'Error:',
  'LBL_PASSWORD' => 'Password:',
  'LBL_EMPLOYEE_NAME' => 'Employee Name:',
  'LBL_USER_NAME' => 'User Name:',
  'LBL_FIRST_NAME' => 'First Name:',
  'LBL_LAST_NAME' => 'Last Name:',
  'LBL_EMPLOYEE_SETTINGS' => 'Employee Settings',
  'LBL_THEME' => 'Theme:',
  'LBL_LANGUAGE' => 'Language:',
  'LBL_ADMIN' => 'Administrator:',
  'LBL_EMPLOYEE_INFORMATION' => 'Employee Information',
  'LBL_OFFICE_PHONE' => 'Office Phone:',
  'LBL_REPORTS_TO' => 'Reports to Id:',
  'LBL_REPORTS_TO_NAME' => 'Reports to',
  'LBL_OTHER_PHONE' => 'Other:',
  'LBL_OTHER_EMAIL' => 'Other Email:',
  'LBL_NOTES' => 'Notes:',
  'LBL_DEPARTMENT' => 'Department:',
  'LBL_TITLE' => 'Title:',
  'LBL_ANY_ADDRESS' => 'Any Address:',
  'LBL_ANY_PHONE' => 'Any Phone:',
  'LBL_ANY_EMAIL' => 'Any Email:',
  'LBL_ADDRESS' => 'Address:',
  'LBL_CITY' => 'City:',
  'LBL_STATE' => 'State:',
  'LBL_POSTAL_CODE' => 'Postal Code:',
  'LBL_COUNTRY' => 'Country:',
  'LBL_NAME' => 'Name:',
  'LBL_MOBILE_PHONE' => 'Mobile:',
  'LBL_OTHER' => 'Other:',
  'LBL_FAX' => 'Fax:',
  'LBL_EMAIL' => 'Email Address:',
  'LBL_HOME_PHONE' => 'Home Phone:',
  'LBL_WORK_PHONE' => 'Work Phone:',
  'LBL_ADDRESS_INFORMATION' => 'Address Information',
  'LBL_EMPLOYEE_STATUS' => 'Employee Status:',
  'LBL_PRIMARY_ADDRESS' => 'Primary Address:',
  'LBL_SAVED_SEARCH' => 'Layout Options',
  'LBL_CREATE_USER_BUTTON_TITLE' => 'Create User [Alt+N]',
  'LBL_CREATE_USER_BUTTON_LABEL' => 'Create User',
  'LBL_CREATE_USER_BUTTON_KEY' => 'N',
  'LBL_FAVORITE_COLOR' => 'Favorite Color:',
  'LBL_MESSENGER_ID' => 'IM Name:',
  'LBL_MESSENGER_TYPE' => 'IM Type:',
  'ERR_EMPLOYEE_NAME_EXISTS_1' => 'The employee name ',
  'ERR_EMPLOYEE_NAME_EXISTS_2' => ' already exists.  Duplicate employee names are not allowed.  Change the employee name to be unique.',
  'ERR_LAST_ADMIN_1' => 'The employee name "',
  'ERR_LAST_ADMIN_2' => '" is the last employee with administrator access.  At least one employee must be an administrator.',
  'LNK_NEW_EMPLOYEE' => 'Create Employee',
  'LNK_EMPLOYEE_LIST' => 'View Employees',
  'ERR_DELETE_RECORD' => 'You must specify a record number to delete the account.',
  'LBL_LIST_EMPLOYEE_STATUS' => 'Employee Status',

  'LBL_SUGAR_LOGIN' => 'Is Sugar User',  
  'LBL_RECEIVE_NOTIFICATIONS' => 'Notify on Assignment',  
  'LBL_IS_ADMIN' => 'Is Administrator',  
  'LBL_GROUP' => 'Group User',
  'LBL_PORTAL_ONLY'	=> 'Portal Only User',
  'LBL_PHOTO'	=> 'Photo',
  'LBL_DELETE_USER_CONFIRM'           => 'This Employee is also a User. Deleting the Employee record will also delete the User record, and the User will no longer be able to access the application. Do you want to proceed with deleting this record?',
  'LBL_DELETE_EMPLOYEE_CONFIRM'       => 'Are you sure you want to delete this employee?',
  
);


?>
